@@ -11,9 +11,10 @@ _default = {
     "fs_cache_file_ext": "",
     "logger": None,
     "lmdb_map_size": consts.SIZE_MB * 4,
-    "lmdb_filename": defaults.CACHE_DEFAULT_FILENAME,
+    "lmdb_filename": defaults.CACHE_DEFAULT_FILENAME + ".lmdb",
     "dbm_filename": defaults.CACHE_DEFAULT_FILENAME + ".dbm",
-    "lsmdb_filename": defaults.CACHE_DEFAULT_FILENAME + ".ldb",
+    "leveldb_filename": defaults.CACHE_DEFAULT_FILENAME + ".lvldb",
+    "lsmdb_filename": defaults.CACHE_DEFAULT_FILENAME + ".lsmdb",
     "redis_unix_socket_path": None,
     "redis_host": "localhost",
     "redis_port": 6379,
